@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Return the borders of states and provinces
 
-our $VERSION = '0.0105';
+our $VERSION = '0.0106';
 
 use strictures 2;
 use Moo;
@@ -207,7 +207,7 @@ Geography::States::Borders - Return the borders of states and provinces
 
 =head1 VERSION
 
-version 0.0105
+version 0.0106
 
 =head1 SYNOPSIS
 
@@ -218,10 +218,11 @@ version 0.0105
 
 =head1 DESCRIPTION
 
-C<Geography::States::Borders> returns the borders of states and provinces.
+C<Geography::States::Borders> returns the border states (or provinces)
+of given states or provinces.
 
-* Currently the only recognized countries are Australia, Canada,
-Brazil, The Netherlands, and the USA.
+* Currently the recognized countries are Australia, Canada, Brazil,
+the Netherlands, and the USA.
 
 =head1 ATTRIBUTES
 
@@ -243,12 +244,15 @@ Create a new C<Geography::States::Borders> object.
 
 =head2 borders
 
-  @states = $geo->borders($state_code);
+  $states = $geo->borders($state_code);
 
-Return the bordering states of the given state code.
+Return a hash reference of the bordering states of the given state
+code.
 
 =head1 SEE ALSO
 
+The F<t/methods.t> file in this distribution
+
 L<Moo>
 
 =head1 AUTHOR
